@@ -30,6 +30,7 @@
 #include "src/settings/kdesvnsettings.h"
 #include "src/helpers/sub2qt.h"
 #include "src/helpers/sshagent.h"
+#include "kdesvndinterface.h"
 
 #include <stdlib.h>
 #include <math.h>
@@ -42,18 +43,14 @@
 #include <kdebug.h>
 #include <kdemacros.h>
 #include <kmessagebox.h>
-#include <kinstance.h>
+#include <kcomponentdata.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurl.h>
 #include <ktempdir.h>
-#include <ksock.h>
-#include <dcopclient.h>
-#include <qcstring.h>
 #include <kmimetype.h>
 #include <krun.h>
-#include <qtextstream.h>
 
 #include <stdlib.h>
 #include <math.h>
@@ -79,7 +76,7 @@ public:
     svn::ContextP m_CurrentContext;
     svn::Client* m_Svnclient;
 
-    svn::Revision urlToRev(const KURL&);
+    svn::Revision urlToRev(const KUrl&);
 
 };
 
@@ -116,14 +113,14 @@ KioSvnData::~KioSvnData()
     m_CurrentContext = 0;
 }
 
-svn::Revision KioSvnData::urlToRev(const KURL&url)
+svn::Revision KioSvnData::urlToRev(const KUrl&url)
 {
     QMap<QString,QString> q = url.queryItems();
 
     /* we try to check if it is ssh and try to get a password for it */
     QString proto = url.protocol();
 
-    if (proto.find("ssh")!=-1) {
+    if (proto.indexOf("ssh")!=-1) {
         SshAgent ag;
         ag.addSshIdentities();
     }
@@ -137,17 +134,15 @@ svn::Revision KioSvnData::urlToRev(const KURL&url)
     return rev;
 }
 
-
-kio_svnProtocol::kio_svnProtocol(const QCString &pool_socket, const QCString &app_socket)
+kio_svnProtocol::kio_svnProtocol(const QByteArray &pool_socket, const QByteArray &app_socket)
     : SlaveBase("kio_ksvn", pool_socket, app_socket),StreamWrittenCb()
 {
     m_pData=new KioSvnData(this);
-    KGlobal::locale()->insertCatalogue("kdesvn");
+    KGlobal::locale()->insertCatalog("kdesvn");
 }
 
 kio_svnProtocol::~kio_svnProtocol()
 {
-    kdDebug()<<"Delete kio protocol"<<endl;
     delete m_pData;
 }
 
@@ -160,34 +155,46 @@ extern "C"
 
 int kdemain(int argc, char **argv)
 {
-    kdDebug()<<"kdemain" << endl;
-    KInstance instance( "kio_ksvn" );
-   // start the kdesvnd DCOP service
-    QString error;
-    QCString appId;
-
-    kdDebug(7101) << "*** Starting kio_ksvn " << endl;
+    KComponentData componentData("kio_ksvn");
+    kDebug(7101) << "*** Starting kio_ksvn " << endl;
 
     if (argc != 4) {
-        kdDebug(7101) << "Usage: kio_ksvn  protocol domain-socket1 domain-socket2" << endl;
+        kDebug(7101) << "Usage: kio_ksvn  protocol domain-socket1 domain-socket2" << endl;
         exit(-1);
     }
-
     KIO::kio_svnProtocol slave(argv[2], argv[3]);
     slave.dispatchLoop();
-
-    kdDebug(7101) << "*** kio_ksvn Done" << endl;
+    kDebug(7101) << "*** kio_ksvn Done" << endl;
     return 0;
 }
 
 namespace KIO
 {
-/*!
-    \fn kio_svnProtocol::listDir (const KURL&url)
- */
-void kio_svnProtocol::listDir(const KURL&url)
+
+void kio_svnProtocol::listSendDirEntry(const svn::DirEntry&direntry)
 {
-    kdDebug() << "kio_svn::listDir(const KURL& url) : " << url.url() << endl ;
+        QDateTime dt = svn::DateTime(direntry.time());
+        KIO::UDSEntry entry;
+        if (direntry.name().isEmpty()) {
+            kDebug()<<"Skipping empty entry!"<<endl;
+            return;
+        }
+        if (createUDSEntry(direntry.name(),
+            direntry.lastAuthor(),
+            direntry.size(),
+            direntry.kind()==svn_node_dir?true:false,
+            dt.toTime_t(),
+            entry) ) {
+                listEntry(entry,false);
+            }
+}
+
+/*!
+    \fn kio_svnProtocol::listDir (const KUrl&url)
+ */
+void kio_svnProtocol::listDir(const KUrl&url)
+{
+    kDebug() << "kio_svn::listDir(const KUrl& url) : " << url.url() << endl ;
     svn::DirEntries dlist;
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
@@ -195,37 +202,22 @@ void kio_svnProtocol::listDir(const KURL&url)
     }
 
     try {
+        // we ignoring the result 'cause it is done via kiolistener for a smoother insert of items.
         dlist = m_pData->m_Svnclient->list(makeSvnUrl(url),rev,rev,svn::DepthImmediates,false);
     } catch (const svn::ClientException&e) {
         QString ex = e.msg();
-        kdDebug()<<ex<<endl;
-        error(KIO::ERR_CANNOT_ENTER_DIRECTORY,ex);
+        kDebug()<<ex<<endl;
+        error(KIO::ERR_SLAVE_DEFINED,ex);
         return;
     }
-    KIO::UDSEntry entry;
-    totalSize(dlist.size());
-    for (unsigned int i=0; i < dlist.size();++i) {
-        if (!dlist[i] || dlist[i]->name().isEmpty()) {
-            continue;
-        }
-        QDateTime dt = svn::DateTime(dlist[i]->time());
-        if (createUDSEntry(dlist[i]->name(),
-            dlist[i]->lastAuthor(),
-            dlist[i]->size(),
-            dlist[i]->kind()==svn_node_dir?true:false,
-            dt.toTime_t(),
-            entry) ) {
-            listEntry(entry,false);
-        }
-        entry.clear();
-    }
-    listEntry(entry, true );
+    listEntry(KIO::UDSEntry(), true );
     finished();
+    kDebug()<<"Listing finished"<<endl;
 }
 
-void kio_svnProtocol::stat(const KURL& url)
+void kio_svnProtocol::stat(const KUrl& url)
 {
-    kdDebug()<<"kio_svn::stat "<< url << endl;
+    kDebug()<<"kio_svn::stat "<< url << endl;
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
@@ -237,36 +229,34 @@ void kio_svnProtocol::stat(const KURL& url)
          e = m_pData->m_Svnclient->info(makeSvnUrl(url),svn::DepthEmpty,rev,peg);
     } catch  (const svn::ClientException&e) {
         QString ex = e.msg();
-        kdDebug()<<ex<<endl;
+        kDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,ex);
         return;
     }
 
     if (e.count()==0) {
         dummy = true;
-/*        finished();
-        return;*/
     }
 
     KIO::UDSEntry entry;
     QDateTime dt;
     if (dummy) {
-        createUDSEntry(url.filename(),"",0,true,dt.toTime_t(),entry);
+        createUDSEntry(url.fileName(),"",0,true,dt.toTime_t(),entry);
     } else {
         dt = svn::DateTime(e[0].cmtDate());
         if (e[0].kind()==svn_node_file) {
-            createUDSEntry(url.filename(),"",0,false,dt.toTime_t(),entry);
+            createUDSEntry(url.fileName(),"",0,false,dt.toTime_t(),entry);
         } else {
-            createUDSEntry(url.filename(),"",0,true,dt.toTime_t(),entry);
+            createUDSEntry(url.fileName(),"",0,true,dt.toTime_t(),entry);
         }
     }
     statEntry(entry);
     finished();
 }
 
-void kio_svnProtocol::get(const KURL& url)
+void kio_svnProtocol::get(const KUrl& url)
 {
-    kdDebug()<<"kio_svn::get "<< url << endl;
+    kDebug()<<"kio_svn::get "<< url << endl;
     if (m_pData->m_Listener.contextCancel()) {
         finished();
         return;
@@ -275,14 +265,13 @@ void kio_svnProtocol::get(const KURL& url)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    KioByteStream dstream(this,url.filename());
+    KioByteStream dstream(this,url.fileName());
     try {
         m_pData->m_Svnclient->cat(dstream,makeSvnUrl(url),rev,rev);
     } catch (const svn::ClientException&e) {
         QString ex = e.msg();
-        kdDebug()<<ex<<endl;
+        kDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,"Subversion error "+ex);
-        finished();
         return;
     }
     totalSize(dstream.written());
@@ -290,9 +279,9 @@ void kio_svnProtocol::get(const KURL& url)
     finished();
 }
 
-void kio_svnProtocol::mkdir(const KURL &url, int)
+void kio_svnProtocol::mkdir(const KUrl &url, int)
 {
-    kdDebug()<<"kio_svn::mkdir "<< url << endl;
+    kDebug()<<"kio_svn::mkdir "<< url << endl;
     svn::Revision rev = m_pData->urlToRev(url);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
@@ -302,15 +291,17 @@ void kio_svnProtocol::mkdir(const KURL &url, int)
         m_pData->m_Svnclient->mkdir(p,getDefaultLog());
     }catch (const svn::ClientException&e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
+        kDebug()<<"kio_svn::mkdir aborted" << url << endl;
+        return;
     }
-    kdDebug()<<"kio_svn::mkdir finished " << url << endl;
+    kDebug()<<"kio_svn::mkdir finished " << url << endl;
     finished();
 }
 
-void kio_svnProtocol::mkdir(const KURL::List &urls, int)
+void kio_svnProtocol::mkdir(const KUrl::List &urls, int)
 {
     svn::Pathes p;
-    for ( QValueListConstIterator<KURL> it = urls.begin(); it != urls.end() ; ++it ) {
+    for (KUrl::List::const_iterator it = urls.begin(); it != urls.end() ; ++it ) {
         p.append((*it).path());
     }
     try {
@@ -322,25 +313,35 @@ void kio_svnProtocol::mkdir(const KURL::List &urls, int)
     finished();
 }
 
-void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
+void kio_svnProtocol::rename(const KUrl&src,const KUrl&target,KIO::JobFlags flags)
 {
-    kdDebug()<<"kio_svn::rename "<< src << " to " << target <<  endl;
+    kDebug()<<"kio_svn::rename "<< src << " to " << target <<  endl;
+    Q_UNUSED(flags);
+    //bool force  = flags&KIO::Overwrite;
     QString msg;
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
-        m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),force);
-    }catch (const svn::ClientException&e) {
-        error( KIO::ERR_SLAVE_DEFINED,e.msg());
+        m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),false);
+    } catch (const svn::ClientException&e) {
+        if (e.apr_err()==SVN_ERR_ENTRY_EXISTS) {
+            error(KIO::ERR_DIR_ALREADY_EXIST,e.msg());
+        } else {
+            error(KIO::ERR_SLAVE_DEFINED,e.msg());
+        }
+        kDebug()<<"kio_svn::rename aborted" <<  endl;
+        return;
     }
-    kdDebug()<<"kio_svn::rename finished" <<  endl;
+    kDebug()<<"kio_svn::rename finished" <<  endl;
     finished();
 }
 
-void kio_svnProtocol::copy(const KURL&src,const KURL&dest,int permissions,bool overwrite)
+void kio_svnProtocol::copy(const KUrl&src,const KUrl&dest,int permissions,KIO::JobFlags flags)
 {
     Q_UNUSED(permissions);
-    Q_UNUSED(overwrite);
-    kdDebug()<<"kio_svn::copy "<< src << " to " << dest <<  endl;
+    Q_UNUSED(flags);
+    //bool force = flags&KIO::Overwrite;
+
+    kDebug()<<"kio_svn::copy "<< src << " to " << dest <<  endl;
     svn::Revision rev = m_pData->urlToRev(src);
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
@@ -350,17 +351,23 @@ void kio_svnProtocol::copy(const KURL&src,const KURL&dest,int permissions,bool o
     try {
         m_pData->m_Svnclient->copy(makeSvnUrl(src),rev,makeSvnUrl(dest));
     }catch (const svn::ClientException&e) {
-        error( KIO::ERR_SLAVE_DEFINED,e.msg());
+        if (e.apr_err()==SVN_ERR_ENTRY_EXISTS) {
+            error(KIO::ERR_DIR_ALREADY_EXIST,e.msg());
+        } else {
+            error(KIO::ERR_SLAVE_DEFINED,e.msg());
+        }
+        kDebug()<<"kio_svn::copy aborted" <<  endl;
+        return;
     }
     m_pData->dispProgress=false;
-    kdDebug()<<"kio_svn::copy finished" <<  endl;
+    kDebug()<<"kio_svn::copy finished" <<  endl;
     finished();
 }
 
-void kio_svnProtocol::del(const KURL&src,bool isfile)
+void kio_svnProtocol::del(const KUrl&src,bool isfile)
 {
     Q_UNUSED(isfile);
-    kdDebug()<<"kio_svn::del "<< src << endl;
+    kDebug()<<"kio_svn::del "<< src << endl;
     //m_pData->reInitClient();
     svn::Revision rev = m_pData->urlToRev(src);
     if (rev == svn::Revision::UNDEFINED) {
@@ -372,10 +379,12 @@ void kio_svnProtocol::del(const KURL&src,bool isfile)
         m_pData->m_Svnclient->remove(target,false);
     } catch (const svn::ClientException&e) {
         QString ex = e.msg();
-        kdDebug()<<ex<<endl;
+        kDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,ex);
+        kDebug()<<"kio_svn::del aborted" << endl;
+        return;
     }
-    kdDebug()<<"kio_svn::del finished" << endl;
+    kDebug()<<"kio_svn::del finished" << endl;
     finished();
 }
 
@@ -385,14 +394,14 @@ bool kio_svnProtocol::getLogMsg(QString&t)
     return m_pData->m_Listener.contextGetLogMessage(t,_items);
 }
 
-bool kio_svnProtocol::checkWc(const KURL&url)
+bool kio_svnProtocol::checkWc(const KUrl&url)
 {
     if (url.isEmpty()||!url.isLocalFile()) return false;
     svn::Revision peg(svn_opt_revision_unspecified);
     svn::Revision rev(svn_opt_revision_unspecified);
     svn::InfoEntries e;
     try {
-        e = m_pData->m_Svnclient->info(url.prettyURL(),svn::DepthEmpty,rev,peg);
+        e = m_pData->m_Svnclient->info(url.prettyUrl(),svn::DepthEmpty,rev,peg);
     } catch (const svn::ClientException&e) {
         if (SVN_ERR_WC_NOT_DIRECTORY==e.apr_err())
         {
@@ -403,7 +412,7 @@ bool kio_svnProtocol::checkWc(const KURL&url)
     return false;
 }
 
-QString kio_svnProtocol::makeSvnUrl(const KURL&url,bool check_Wc)
+QString kio_svnProtocol::makeSvnUrl(const KUrl&url,bool check_Wc)
 {
     QString res;
     QString proto = svn::Url::transformProtokoll(url.protocol());
@@ -415,7 +424,7 @@ QString kio_svnProtocol::makeSvnUrl(const KURL&url,bool check_Wc)
         }
     }
 
-    QStringList s = QStringList::split("://",res);
+    QStringList s = res.split("://");
     QString base = url.path();
     QString host = url.host();
     QString user = (url.hasUser()?url.user()+(url.hasPass()?":"+url.pass():""):"");
@@ -432,98 +441,72 @@ QString kio_svnProtocol::makeSvnUrl(const KURL&url,bool check_Wc)
 
 bool kio_svnProtocol::createUDSEntry( const QString& filename, const QString& user, long long int size, bool isdir, time_t mtime, KIO::UDSEntry& entry)
 {
-#if 0
-        kdDebug() << "MTime : " << ( long )mtime << endl;
-        kdDebug() << "UDS filename : " << filename << endl;
-        kdDebug()<< "UDS Size: " << size << endl;
-        kdDebug()<< "UDS Dir: " << isdir << endl;
-#endif
-        KIO::UDSAtom atom;
-        atom.m_uds = KIO::UDS_NAME;
-        atom.m_str = filename;
-        entry.append( atom );
-
-        atom.m_uds = KIO::UDS_FILE_TYPE;
-        atom.m_long = isdir ? S_IFDIR : S_IFREG;
-        entry.append( atom );
-
-        atom.m_uds = KIO::UDS_ACCESS;
-        atom.m_long = isdir?0777:0666;
-        entry.append(atom);
-
-
-        atom.m_uds = KIO::UDS_SIZE;
-        atom.m_long = size;
-        entry.append( atom );
-
-        atom.m_uds = KIO::UDS_MODIFICATION_TIME;
-        atom.m_long = mtime;
-        entry.append( atom );
-
-        atom.m_uds = KIO::UDS_USER;
-        atom.m_str = user;
-        entry.append( atom );
-
-        return true;
+    entry.insert(KIO::UDSEntry::UDS_NAME,filename);
+    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE,isdir ? S_IFDIR : S_IFREG);
+    entry.insert(KIO::UDSEntry::UDS_SIZE,size);
+    entry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME,mtime);
+    entry.insert(KIO::UDSEntry::UDS_USER,user);
+    return true;
 }
 
 void kio_svnProtocol::special(const QByteArray& data)
 {
-    kdDebug()<<"kio_svnProtocol::special"<<endl;
-    QDataStream stream(data,IO_ReadOnly);
+    kDebug()<<"kio_svnProtocol::special"<<endl;
+    QByteArray tmpData(data);
+    QDataStream stream(&tmpData,QIODevice::ReadOnly);
     int tmp;
     stream >> tmp;
-    kdDebug() << "kio_svnProtocol::special " << tmp << endl;
+    kDebug() << "kio_svnProtocol::special " << tmp << endl;
     switch (tmp) {
         case SVN_CHECKOUT:
         {
-            KURL repository, wc;
+            KUrl repository, wc;
             int revnumber;
             QString revkind;
             stream >> repository;
             stream >> wc;
             stream >> revnumber;
             stream >> revkind;
-            kdDebug(0) << "kio_svnProtocol CHECKOUT from " << repository.url() << " to " << wc.url() << " at " << revnumber << " or " << revkind << endl;
+            kDebug(0) << "kio_svnProtocol CHECKOUT from " << repository.url() << " to " << wc.url() << " at " << revnumber << " or " << revkind << endl;
             checkout( repository, wc, revnumber, revkind );
             break;
         }
         case SVN_UPDATE:
         {
-            KURL wc;
+            KUrl wc;
             int revnumber;
             QString revkind;
             stream >> wc;
             stream >> revnumber;
             stream >> revkind;
-            kdDebug(0) << "kio_svnProtocol UPDATE " << wc.url() << " at " << revnumber << " or " << revkind << endl;
+            kDebug(0) << "kio_svnProtocol UPDATE " << wc.url() << " at " << revnumber << " or " << revkind << endl;
             update(wc, revnumber, revkind );
             break;
         }
         case SVN_COMMIT:
         {
-            KURL::List wclist;
+            KUrl::List wclist;
             while ( !stream.atEnd() ) {
-                KURL tmp;
+                KUrl tmp;
                 stream >> tmp;
                 wclist << tmp;
             }
-            kdDebug(0) << "kio_svnProtocol COMMIT" << endl;
+            kDebug(0) << "kio_svnProtocol COMMIT" << endl;
             commit( wclist );
             break;
         }
         case SVN_LOG:
         {
-            kdDebug(0) << "kio_svnProtocol LOG" << endl;
+            kDebug(0) << "kio_svnProtocol LOG" << endl;
             int revstart, revend;
             QString revkindstart, revkindend;
-            KURL::List targets;
+            KUrl::List targets;
             stream >> revstart;
             stream >> revkindstart;
             stream >> revend;
             stream >> revkindend;
             while ( !stream.atEnd() ) {
-                KURL tmp;
+                KUrl tmp;
                 stream >> tmp;
                 targets << tmp;
             }
@@ -532,26 +515,26 @@ void kio_svnProtocol::special(const QByteArray& data)
         }
         case SVN_IMPORT:
         {
-            KURL wc,repos;
+            KUrl wc,repos;
             stream >> repos;
             stream >> wc;
-            kdDebug(0) << "kio_ksvnProtocol IMPORT" << endl;
+            kDebug(0) << "kio_ksvnProtocol IMPORT" << endl;
             import(repos,wc);
             break;
         }
         case SVN_ADD:
         {
-            KURL wc;
-            kdDebug(0) << "kio_ksvnProtocol ADD" << endl;
+            KUrl wc;
+            kDebug(0) << "kio_ksvnProtocol ADD" << endl;
             stream >> wc;
             add(wc);
             break;
         }
         case SVN_DEL:
         {
-            KURL::List wclist;
+            KUrl::List wclist;
             while ( !stream.atEnd() ) {
-                KURL tmp;
+                KUrl tmp;
                 stream >> tmp;
                 wclist << tmp;
             }
@@ -560,49 +543,49 @@ void kio_svnProtocol::special(const QByteArray& data)
         }
         case SVN_REVERT:
         {
-            KURL::List wclist;
+            KUrl::List wclist;
             while ( !stream.atEnd() ) {
-                KURL tmp;
+                KUrl tmp;
                 stream >> tmp;
                 wclist << tmp;
             }
-            kdDebug(7128) << "kio_svnProtocol REVERT" << endl;
+            kDebug(7128) << "kio_svnProtocol REVERT" << endl;
             revert(wclist);
             break;
         }
         case SVN_STATUS:
         {
-            KURL wc;
+            KUrl wc;
             bool checkRepos=false;
             bool fullRecurse=false;
             stream >> wc;
             stream >> checkRepos;
             stream >> fullRecurse;
-            kdDebug(0) << "kio_svnProtocol STATUS" << endl;
+            kDebug(0) << "kio_svnProtocol STATUS" << endl;
             status(wc,checkRepos,fullRecurse);
             break;
         }
         case SVN_MKDIR:
         {
-            KURL::List list;
+            KUrl::List list;
             stream >> list;
-            kdDebug(0) << "kio_svnProtocol MKDIR" << endl;
+            kDebug(0) << "kio_svnProtocol MKDIR" << endl;
             mkdir(list,0);
             break;
         }
         case SVN_RESOLVE:
         {
-            KURL url;
+            KUrl url;
             bool recurse;
             stream >> url;
             stream >> recurse;
-            kdDebug(7128) << "kio_svnProtocol RESOLVE" << endl;
+            kDebug(7128) << "kio_svnProtocol RESOLVE" << endl;
             wc_resolve(url,recurse);
             break;
         }
         case SVN_SWITCH:
         {
-            KURL wc,url;
+            KUrl wc,url;
             bool recurse;
             int revnumber;
             QString revkind;
@@ -611,13 +594,13 @@ void kio_svnProtocol::special(const QByteArray& data)
             stream >> recurse;
             stream >> revnumber;
             stream >> revkind;
-            kdDebug(7128) << "kio_svnProtocol SWITCH" << endl;
+            kDebug(7128) << "kio_svnProtocol SWITCH" << endl;
             wc_switch(wc,url,recurse,revnumber,revkind);
             break;
         }
         case SVN_DIFF:
         {
-            KURL url1,url2;
+            KUrl url1,url2;
             int rev1, rev2;
             bool recurse;
             QString revkind1, revkind2;
@@ -632,12 +615,12 @@ void kio_svnProtocol::special(const QByteArray& data)
             break;
         }
         default:
-            {kdDebug()<<"Unknown special" << endl;}
+            {kDebug()<<"Unknown special" << endl;}
     }
     finished();
 }
 
-void kio_svnProtocol::update(const KURL&url,int revnumber,const QString&revkind)
+void kio_svnProtocol::update(const KUrl&url,int revnumber,const QString&revkind)
 {
     svn::Revision where(revnumber,revkind);
     /* update is always local - so make a path instead URI */
@@ -653,7 +636,7 @@ void kio_svnProtocol::update(const KURL&url,int revnumber,const QString&revkind)
     }
 }
 
-void kio_svnProtocol::status(const KURL&wc,bool cR,bool rec)
+void kio_svnProtocol::status(const KUrl&wc,bool cR,bool rec)
 {
     svn::Revision where = svn::Revision::UNDEFINED;
     svn::StatusEntries dlist;
@@ -664,55 +647,54 @@ void kio_svnProtocol::status(const KURL&wc,bool cR,bool rec)
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
     }
-    kdDebug()<<"Status got " << dlist.count() << " entries." << endl;
-    for (unsigned j=0;j<dlist.count();++j) {
+    kDebug()<<"Status got " << dlist.count() << " entries." << endl;
+    for (long j=0;j<dlist.count();++j) {
         if (!dlist[j]) {
             continue;
         }
-        //QDataStream stream(params, IO_WriteOnly);
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"path",dlist[j]->path());
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"text",QString::number(dlist[j]->textStatus()));
-        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "prop",
+        //QDataStream stream(params, QIODevice::WriteOnly);
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"path",dlist[j]->path());
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"text",QString::number(dlist[j]->textStatus()));
+        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustified( 10,'0' )+ "prop",
                     QString::number(dlist[j]->propStatus()));
-        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "reptxt",
+        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustified( 10,'0' )+ "reptxt",
                     QString::number(dlist[j]->reposTextStatus()));
-        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "repprop",
+        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustified( 10,'0' )+ "repprop",
                     QString::number(dlist[j]->reposPropStatus()));
-        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "rev",
+        setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustified( 10,'0' )+ "rev",
                     QString::number(dlist[j]->entry().cmtRev()));
         m_pData->m_Listener.incCounter();
     }
 }
 
-void kio_svnProtocol::commit(const KURL::List&url)
+void kio_svnProtocol::commit(const KUrl::List&url)
 {
     /// @todo replace with direct call to kdesvn?
-    QByteArray reply;
-    QByteArray params;
-    QCString replyType;
     QString msg;
 
-    if (!dcopClient()->call("kded","kdesvnd","get_logmsg()",params,replyType,reply)) {
-        msg = "Communication with dcop failed";
-        kdWarning()<<msg<<endl;
+    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
+    if(!kdesvndInterface.isValid())
+    {
+       kWarning() << "Communication with KDED:KdeSvnd failed";
+       return;
+    }
+
+    QDBusReply<QStringList> res = kdesvndInterface.get_logmsg();
+    if ( !res.isValid() )
+    {
+        kWarning() << "Unexpected reply type";
         return;
     }
-    if (replyType!="QStringList") {
-        msg = "Wrong reply type";
-        kdWarning()<<msg<<endl;
-        return;
-    }
-    QDataStream stream2(reply,IO_ReadOnly);
-    QStringList lt;
-    stream2>>lt;
+    QStringList lt = res;
+
     if (lt.count()!=1) {
         msg = "Wrong or missing log (may cancel pressed).";
-        kdDebug()<< msg << endl;
+        kDebug()<< msg << endl;
         return;
     }
     msg = lt[0];
-    QValueList<svn::Path> targets;
-    for (unsigned j=0; j<url.count();++j) {
+    svn::Pathes targets;
+    for (long j=0; j<url.count();++j) {
         targets.push_back(svn::Path(url[j].path()));
     }
     svn::Revision nnum=svn::Revision::UNDEFINED;
@@ -721,45 +703,45 @@ void kio_svnProtocol::commit(const KURL::List&url)
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
-    for (unsigned j=0;j<url.count();++j) {
+    for (long j=0;j<url.count();++j) {
         QString userstring;
         if (nnum!=svn::Revision::UNDEFINED) {
             userstring = i18n( "Committed revision %1." ).arg(nnum.toString());
         } else {
             userstring = i18n ( "Nothing to commit." );
         }
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "path", url[j].path() );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "action", "0" );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "kind", "0" );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "mime_t", "" );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "content", "0" );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "prop", "0" );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "rev" , QString::number(nnum) );
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "string", userstring );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "path", url[j].path() );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "action", "0" );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "kind", "0" );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "mime_t", "" );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "content", "0" );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "prop", "0" );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "rev" , QString::number(nnum) );
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "string", userstring );
         m_pData->m_Listener.incCounter();
     }
 }
 
-void kio_svnProtocol::checkout(const KURL&src,const KURL&target,const int rev, const QString&revstring)
+void kio_svnProtocol::checkout(const KUrl&src,const KUrl&target,const int rev, const QString&revstring)
 {
     svn::Revision where(rev,revstring);
     svn::Revision peg = svn::Revision::UNDEFINED;
     svn::Path _target(target.path());
     try {
-        KURL _src = makeSvnUrl(src);
+        KUrl _src = makeSvnUrl(src);
         m_pData->m_Svnclient->checkout(_src.url(),_target,where,peg,svn::DepthInfinity,false,false);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
 }
 
-void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int revend, const QString&revstringend, const KURL::List&urls)
+void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int revend, const QString&revstringend, const KUrl::List&urls)
 {
     svn::Revision start(revstart,revstringstart);
     svn::Revision end(revend,revstringend);
     svn::LogEntriesPtr logs;
 
-    for (unsigned j = 0; j<urls.count();++j) {
+    for (long j = 0; j<urls.count();++j) {
         logs = 0;
         try {
             logs = m_pData->m_Svnclient->log(makeSvnUrl(urls[j]),start,end,svn::Revision::UNDEFINED,true,true,0);
@@ -768,32 +750,32 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
             break;
         }
         if (!logs) {
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify(10,'0')+"path",urls[j].path());
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify(10,'0')+"string",
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10,'0')+"path",urls[j].path());
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified(10,'0')+"string",
                 i18n("Empty logs"));
             m_pData->m_Listener.incCounter();
             continue;
         }
-        for (unsigned int i = 0; i < logs->count();++i) {
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "path",urls[j].path());
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "rev",
+        for (long i = 0; i < logs->count();++i) {
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "path",urls[j].path());
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "rev",
                 QString::number( (*logs)[i].revision));
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"author",
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"author",
                 (*logs)[i].author);
-            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"logmessage",
+            setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+"logmessage",
                 (*logs)[i].message);
             m_pData->m_Listener.incCounter();
-            for (unsigned z = 0; z<(*logs)[i].changedPaths.count();++z) {
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "rev",
+            for (long z = 0; z<(*logs)[i].changedPaths.count();++z) {
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "rev",
                     QString::number( (*logs)[i].revision));
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "path",urls[j].path());
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "loggedpath",
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "path",urls[j].path());
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedpath",
                     (*logs)[i].changedPaths[z].path);
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "loggedaction",
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedaction",
                     QChar((*logs)[i].changedPaths[z].action));
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "loggedcopyfrompath",
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedcopyfrompath",
                     (*logs)[i].changedPaths[z].copyFromPath);
-                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "loggedcopyfromrevision",
+                setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "loggedcopyfromrevision",
                     QString::number((*logs)[i].changedPaths[z].copyFromRevision));
                 m_pData->m_Listener.incCounter();
             }
@@ -801,10 +783,10 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
     }
 }
 
-void kio_svnProtocol::revert(const KURL::List&l)
+void kio_svnProtocol::revert(const KUrl::List&l)
 {
-    QValueList<svn::Path> list;
-    for (unsigned j=0; j<l.count();++j) {
+    svn::Pathes list;
+    for (long j=0; j<l.count();++j) {
         list.append(svn::Path(l[j].path()));
     }
     svn::Targets target(list);
@@ -815,7 +797,7 @@ void kio_svnProtocol::revert(const KURL::List&l)
     }
 }
 
-void kio_svnProtocol::wc_switch(const KURL&wc,const KURL&target,bool rec,int rev,const QString&revstring)
+void kio_svnProtocol::wc_switch(const KUrl&wc,const KUrl&target,bool rec,int rev,const QString&revstring)
 {
     svn::Revision where(rev,revstring);
     svn::Path wc_path(wc.path());
@@ -826,7 +808,7 @@ void kio_svnProtocol::wc_switch(const KURL&wc,const KURL&target,bool rec,int rev
     }
 }
 
-void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QString&rstring1,int rnum2, const QString&rstring2,bool rec)
+void kio_svnProtocol::diff(const KUrl&uri1,const KUrl&uri2,int rnum1,const QString&rstring1,int rnum2, const QString&rstring2,bool rec)
 {
     QByteArray ex;
     /// @todo read settings for diff (ignore contentype)
@@ -836,11 +818,11 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
         QString u1 = makeSvnUrl(uri1,true);
         QString u2 = makeSvnUrl(uri2,true);
         KTempDir tdir;
-        kdDebug() << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
+        kDebug() << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
             << u2 << " at revision " << r2.toString()
             << endl ;
 
-        tdir.setAutoDelete(true);
+        tdir.setAutoRemove(true);
             ex = m_pData->m_Svnclient->diff(svn::Path(tdir.name()),
                                             u1,u2,svn::Path(),r1, r2,rec?svn::DepthInfinity:svn::DepthEmpty,false,false,false);
     } catch (const svn::ClientException&e) {
@@ -848,14 +830,14 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
         return;
     }
     QString out = QString::FROMUTF8(ex);
-    QTextIStream stream(&out);
+    QTextStream stream(&out);
     while (!stream.atEnd()) {
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "diffresult",stream.readLine());
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustified( 10,'0' )+ "diffresult",stream.readLine());
         m_pData->m_Listener.incCounter();
     }
 }
 
-void kio_svnProtocol::import(const KURL& repos, const KURL& wc)
+void kio_svnProtocol::import(const KUrl& repos, const KUrl& wc)
 {
     try {
         QString target = makeSvnUrl(repos);
@@ -868,7 +850,7 @@ void kio_svnProtocol::import(const KURL& repos, const KURL& wc)
     finished();
 }
 
-void kio_svnProtocol::add(const KURL& wc)
+void kio_svnProtocol::add(const KUrl& wc)
 {
     QString path = wc.path();
     try {
@@ -881,10 +863,10 @@ void kio_svnProtocol::add(const KURL& wc)
     finished();
 }
 
-void kio_svnProtocol::wc_delete(const KURL::List&l)
+void kio_svnProtocol::wc_delete(const KUrl::List&l)
 {
     svn::Pathes p;
-    for ( QValueListConstIterator<KURL> it = l.begin(); it != l.end() ; ++it ) {
+    for (KUrl::List::const_iterator it = l.begin(); it != l.end() ; ++it ) {
         p.append((*it).path());
     }
     try {
@@ -896,7 +878,7 @@ void kio_svnProtocol::wc_delete(const KURL::List&l)
     finished();
 }
 
-void kio_svnProtocol::wc_resolve(const KURL&url,bool recurse)
+void kio_svnProtocol::wc_resolve(const KUrl&url,bool recurse)
 {
     try {
         svn::Depth depth=recurse?svn::DepthInfinity:svn::DepthEmpty;
@@ -913,10 +895,10 @@ void kio_svnProtocol::streamWritten(const KIO::filesize_t current)
     processedSize(current);
 }
 
-void kio_svnProtocol::streamSendMime(KMimeMagicResult* mt)
+void kio_svnProtocol::streamSendMime(KMimeType::Ptr mt)
 {
     if (mt) {
-        mimeType(mt->mimeType());
+        mimeType(mt->name());
     }
 }
 
