@@ -17,24 +17,27 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#include "ssltrustprompt_impl.h"
 #include "src/settings/kdesvnsettings.h"
+#include "ssltrustprompt_impl.h"
 
 #include <klocale.h>
 #include <qlabel.h>
-#include <qtable.h>
-#include <qvbox.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfigbase.h>
 #include <kconfig.h>
-#include <kdialogbase.h>
+#include <KDialog>
+#include <KVBox>
 #include <ktextbrowser.h>
 
 SslTrustPrompt_impl::SslTrustPrompt_impl(const QString&host,QWidget *parent, const char *name)
-    :SslTrustPrompt(parent, name)
+//     :SslTrustPrompt(parent, name)
+    : QWidget(parent)
 {
+    setupUi(this);
+    setObjectName(name);
+
     m_MainLabel->setText("<p align=\"center\"><b>"+
         i18n("Error validating server certificate for '%1'").arg(host)+
         QString("</b></p>"));
@@ -47,10 +50,13 @@ SslTrustPrompt_impl::SslTrustPrompt_impl(const QString&host,QWidget *parent, con
 bool SslTrustPrompt_impl::sslTrust(const QString&host,const QString&fingerprint,const QString&validFrom,const QString&validUntil,const QString&issuerName,const QString&realm,const QStringList&reasons,bool*ok,bool*saveit)
 {
     SslTrustPrompt_impl*ptr=0;
-    KDialogBase dlg(i18n("Trust ssl certificate"));
-    dlg.setButtonText(KDialogBase::Yes,i18n("Accept permanently"));
-    dlg.setButtonText(KDialogBase::No,i18n("Accept temporarily"));
-    dlg.setButtonCancel(KGuiItem(i18n("Reject")));
+//     KDialogBase dlg(i18n("Trust ssl certificate"));
+    KDialog dlg(0);
+    dlg.setCaption(i18n("Trust ssl certificate"));
+    dlg.setButtonText(KDialog::Yes,i18n("Accept permanently"));
+    dlg.setButtonText(KDialog::No,i18n("Accept temporarily"));
+//     dlg.setButtonCancel(KGuiItem(i18n("Reject")));
+    dlg.setButtonText(KDialog::Cancel, i18n("Reject"));
 
     static QString rb = "<tr><td>";
     static QString rs = "</td><td>";
@@ -59,7 +65,7 @@ bool SslTrustPrompt_impl::sslTrust(const QString&host,const QString&fingerprint,
     if (reasons.count()>0) {
         text+="<p align=\"center\">";
         text+="<h2>"+i18n("Failure reasons")+"</h2><hline>";
-        for (unsigned int i = 0; i < reasons.count();++i) {
+        for (int i = 0; i < reasons.count();++i) {
             text+=reasons[i]+"<br><hline>";
         }
         text+="</p>";
@@ -74,19 +80,24 @@ bool SslTrustPrompt_impl::sslTrust(const QString&host,const QString&fingerprint,
     text+=rb+i18n("Fingerprint")+rs+fingerprint+re;
     text+="</table></p></body></html>";
 
-    QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
-    dlg.resize(dlg.configDialogSize(*(Kdesvnsettings::self()->config()),"trustssldlg"));
+//     QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
+    KVBox *Dialog1Layout = new KVBox(&dlg);
+    dlg.setMainWidget(Dialog1Layout);
+
+// KDE4 port - pv    dlg.resize(dlg.configDialogSize(*(Kdesvnsettings::self()->config()),"trustssldlg"));
     ptr = new SslTrustPrompt_impl(host,Dialog1Layout);
     ptr->m_ContentText->setText(text);
     int i = dlg.exec();
-    dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),"trustssldlg",false);
+// KDE4 port - pv    dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),"trustssldlg",false);
     *saveit = false;
     *ok = true;
-    if (i == KDialogBase::Yes) {
+    if (i == KDialog::Yes) {
         *saveit = true;
-    } else if (i==KDialogBase::Cancel) {
+    } else if (i==KDialog::Cancel) {
         *ok = false;
     }
     return *ok;
 }
+
 #include "ssltrustprompt_impl.moc"
+
