@@ -26,9 +26,10 @@
 #include <qcheckbox.h>
 #include <klineedit.h>
 
-CmdExecSettings_impl::CmdExecSettings_impl(QWidget* parent, const char* name, WFlags fl)
-: CmdExecSettings(parent,name,fl)
+CmdExecSettings_impl::CmdExecSettings_impl(QWidget* parent)
+: QWidget(parent)
 {
+    setupUi(this);
     kcfg_cmdline_log_minline->setSpecialValueText(i18n("No minimum"));
     kcfg_cmdline_log_minline->setEnabled(kcfg_cmdline_show_logwindow->isChecked());
     kcfg_kio_standard_logmsg->setEnabled(kcfg_kio_use_standard_logmsg->isChecked());
