@@ -20,18 +20,18 @@
 #include "ccontextlistener.h"
 #include "src/settings/kdesvnsettings.h"
 #include "src/ksvnwidgets/authdialogimpl.h"
-#include "src/ksvnwidgets/logmsg_impl.h"
+#include "src/ksvnwidgets/commitmsg_impl.h"
 #include "src/ksvnwidgets/ssltrustprompt_impl.h"
 #include "src/ksvnwidgets/pwstorage.h"
 
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kinputdialog.h>
-#include <kpassdlg.h>
+#include <kpassworddialog.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
 
-#include <qtextstream.h>
+#include <QTextStream>
 #include <qthread.h>
 
 class CContextListenerData
@@ -43,12 +43,12 @@ public:
     // data
     bool m_cancelMe;
     QMutex m_CancelMutex;
-    PwStorage pws;
+
+    bool noDialogs;
 };
 
-
 CContextListenerData::CContextListenerData()
-    : m_cancelMe(false),m_CancelMutex()
+    : m_cancelMe(false),m_CancelMutex(),noDialogs(false)
 {
 }
 
@@ -92,7 +92,8 @@ const QString CContextListener::notify_state_strings[]={
     I18N_NOOP("unchanged"),
     I18N_NOOP("item wasn't present"),
     I18N_NOOP("unversioned item obstructed work"),
-    I18N_NOOP("Pristine state was modified."), // should send a signal with path instead of message?
+    // I18N_NOOP("Pristine state was modified."), // should send a signal with path instead of message?
+    QString::null,
     I18N_NOOP("Modified state had mods merged in."),
     I18N_NOOP("Modified state got conflicting mods.")
 };
@@ -102,31 +103,39 @@ QString CContextListener::NotifyAction(svn_wc_notify_action_t action)
     if (action>=smax_actionstring||action<0) {
         return QString::null;
     }
-    return action_strings[action].isEmpty()?QString::null:i18n(action_strings[action]);
+    return action_strings[action].isEmpty() ? QString(): /*i18n(*/action_strings[action]/*)*/;
 }
 
 QString CContextListener::NotifyState(svn_wc_notify_state_t state)
 {
     if (state > svn_wc_notify_state_conflicted || state<0) return QString::null;
-    return notify_state_strings[state].isEmpty()?QString::null:i18n(notify_state_strings[state]);
+    return notify_state_strings[state].isEmpty()?QString():/*i18n(*/notify_state_strings[state]/*)*/;
 }
 
 CContextListener::CContextListener(QObject *parent, const char *name)
- : QObject(parent, name), svn::ContextListener(),ref_count()
+ : QObject(parent), svn::ContextListener(),ref_count()
 {
+    setObjectName(name);
     m_Data = new CContextListenerData();
 }
 
-
 CContextListener::~CContextListener()
 {
     disconnect();
     delete m_Data;
 }
 
+bool CContextListener::contextGetCachedLogin (const QString & realm,QString & username,QString & password)
+{
+    PwStorage::self()->getCachedLogin(realm,username,password);
+    return true;
+}
+
 bool CContextListener::contextGetSavedLogin (const QString & realm,QString & username,QString & password)
 {
-    m_Data->pws.getLogin(realm,username,password);
+    PwStorage::self()->getLogin(realm,username,password);
+    PwStorage::self()->setCachedLogin(realm,username,password);
+    /* the return value isn't interesting to us... */
     return true;
 }
 
@@ -145,7 +154,10 @@ bool CContextListener::contextGetLogin (
         password=auth.Password();
         maySave = (Kdesvnsettings::passwords_in_wallet()?false:auth.maySave());
         if (Kdesvnsettings::passwords_in_wallet() && auth.maySave()) {
-            m_Data->pws.setLogin(realm,username,password);
+            PwStorage::self()->setLogin(realm,username,password);
+        }
+        if (Kdesvnsettings::use_password_cache()) {
+            PwStorage::self()->setCachedLogin(realm,username,password);
         }
         emit waitShow(false);
         return true;
@@ -171,11 +183,14 @@ void CContextListener::contextNotify (const char *path,
                     svn_wc_notify_state_t prop_state,
                     svn_revnum_t revision)
 {
+    Q_UNUSED(mime_type);
+    Q_UNUSED(prop_state);
+
     QString msg;
     QString aString = NotifyAction(action);
 
     if (!aString.isEmpty()) {
-        QTextStream ts(&msg,IO_WriteOnly);
+        QTextStream ts(&msg,QIODevice::WriteOnly);
         ts << NotifyAction(action) << " " << QString::FROMUTF8(path);
         if (revision>-1) {
             ts << " (Rev "<<revision<<")";
@@ -222,7 +237,7 @@ bool CContextListener::contextGetLogMessage (QString & msg,const svn::CommitItem
 {
     bool isOk = false;
     emit waitShow(true);
-    QString logMessage = Logmsg_impl::getLogmessage(items,&isOk,0,0,0);
+    QString logMessage = Commitmsg_impl::getLogmessage(items,&isOk,0,0,0);
     if (isOk) {
         msg = logMessage;
     }
@@ -255,10 +270,14 @@ svn::ContextListener::SslServerTrustAnswer CContextListener::contextSslServerTru
 
 bool CContextListener::contextSslClientCertPrompt (QString & certFile)
 {
-    kdDebug()<<"CContextListener::contextSslClientCertPrompt "
+    kDebug()<<"CContextListener::contextSslClientCertPrompt "
         << certFile << endl;
     emit waitShow(true);
-    QString afile = KFileDialog::getOpenFileName(QString::null,
+//     QString afile = KFileDialog::getOpenFileName(QString::null,
+//         QString::null,
+//         0,
+//         i18n("Open a file with a #PKCS12 certificate"));
+    QString afile = KFileDialog::getOpenFileName(KUrl(),
         QString::null,
         0,
         i18n("Open a file with a #PKCS12 certificate"));
@@ -272,7 +291,8 @@ bool CContextListener::contextSslClientCertPrompt (QString & certFile)
 
 bool CContextListener::contextLoadSslClientCertPw(QString&password,const QString&realm)
 {
-    return m_Data->pws.getCertPw(realm,password);
+    PwStorage::self()->getCertPw(realm,password);
+    return true;
 }
 
 bool CContextListener::contextSslClientCertPwPrompt (QString & password,
@@ -280,18 +300,22 @@ bool CContextListener::contextSslClientCertPwPrompt (QString & password,
 {
     maysave = false;
     emit waitShow(true);
-    QCString npass;
+    QString npass;
     int keep = 1;
-    int res = KPasswordDialog::getPassword(npass,
-        i18n("Enter password for realm %1").arg(realm),
-        &keep);
+    KPasswordDialog dlg(0);
+    dlg.setPrompt(i18n("Enter password for realm %1",realm));
+    dlg.setWindowTitle(realm);
+    int res = dlg.exec();
+    if (res == QDialog::Accepted)
+        npass = dlg.password();
+
     emit waitShow(false);
     if (res!=KPasswordDialog::Accepted) {
         return false;
     }
     maysave = (Kdesvnsettings::passwords_in_wallet()?false:keep!=0);
     if (Kdesvnsettings::store_passwords() && keep) {
-        m_Data->pws.setCertPw(realm,password);
+        PwStorage::self()->setCertPw(realm,password);
     }
     password = npass;
     return true;
@@ -326,7 +350,7 @@ QStringList CContextListener::failure2Strings(apr_uint32_t acceptedFailures)
 
 QString CContextListener::translate(const QString&what)
 {
-    return i18n(what);
+    return i18n(what.toLocal8Bit());
 }
 
 /*!
