@@ -20,23 +20,29 @@
 #ifndef SVNLOGDLGIMP_H
 #define SVNLOGDLGIMP_H
 
-#include "svnlogdlg.h"
+#include "ui_svnlogdlg.h"
 #include "simple_logcb.h"
 #include "src/svnqt/log_entry.hpp"
 #include "src/svnqt/client.hpp"
 #include "src/svnqt/shared_pointer.hpp"
 
 #include <qsize.h>
+#include <QKeyEvent>
 #include <qregexp.h>
 
 class LogListViewItem;
+class QTreeWidgetItem;
 class SvnActions;
+class QTreeWidget;
+class SvnLogModel;
+class QSortFilterProxyModel;
+class QModelIndex;
 
-class SvnLogDlgImp: public SvnLogDialogData,public SimpleLogCb
+class SvnLogDlgImp: public KDialog,public Ui::LogDialog,public SimpleLogCb
 {
 Q_OBJECT
 public:
-    SvnLogDlgImp(SvnActions*,QWidget *parent = 0, const char *name = 0,bool modal=true);
+    SvnLogDlgImp(SvnActions*,QWidget *parent = 0, const char *name = 0, bool modal=true);
     virtual ~SvnLogDlgImp();
     void dispLog(const svn::SharedPointer<svn::LogEntriesMap>&,const QString&,const QString&,const svn::Revision&peg,const QString&pegUrl);
     void saveSize();
@@ -48,24 +54,22 @@ signals:
     void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
     void makeCat(const svn::Revision&,const QString&,const QString&,const svn::Revision&,QWidget*);
 
-protected slots:
-    virtual void slotSelectionChanged(QListViewItem*);
 protected slots:
     virtual void slotDispPrevious();
     virtual void slotDispSelected();
-    virtual void slotItemClicked(int,QListViewItem*,const QPoint &,int);
     virtual void slotRevisionSelected();
 protected:
     QString _name;
     QString _base;
     static const char* groupName;
-    LogListViewItem *m_first,*m_second;
     SvnActions*m_Actions;
     bool m_ControlKeyDown;
     virtual void keyPressEvent (QKeyEvent * e);
     virtual void keyReleaseEvent (QKeyEvent * e);
-    virtual void slotBlameItem();
     svn::SharedPointer<svn::LogEntriesMap> m_Entries;
+    SvnLogModel*m_CurrentModel;
+    QSortFilterProxyModel*m_SortModel;
+
     QString _bugurl;
 
     void dispLog(const svn::SharedPointer<svn::LogEntriesMap>&);
@@ -74,12 +78,17 @@ protected:
 
 protected slots:
     virtual void slotListEntries();
-    virtual void slotEntriesSelectionChanged();
-    virtual void slotSingleContext(QListViewItem*, const QPoint &, int);
-    virtual void slotSingleDoubleClicked(QListViewItem*);
+    virtual void slotChangedPathContextMenu(const QPoint&);
+    virtual void slotSingleDoubleClicked(QTreeWidgetItem*,int);
     virtual void slotGetLogs();
+    virtual void slotBlameItem();
+
+    virtual void slotSelectionChanged(const QItemSelection&, const QItemSelection&);
+    virtual void slotCustomContextMenu(const QPoint&);
 
 protected:
+    /* it works 'cause we use single selection only */
+    QModelIndex selectedRow(int column=0);
     void replaceBugids(QString&msg);
     QString genReplace(const QString&);
     svn::Revision m_peg;
