@@ -84,7 +84,7 @@ namespace svn
                 options,
                 path.cstr(),
                 peg_revision,ddata.r1().revision(),ddata.r2().revision(),
-                relativeTo.length()>0?relativeTo.cstr():QByteArray(0),
+                relativeTo.length()>0?relativeTo.cstr():QByteArray(/*0*/),
                 internal::DepthToSvn(depth),
                 ignoreAncestry,noDiffDeleted,ignore_contenttype,
                 APR_LOCALE_CHARSET,
@@ -147,7 +147,7 @@ namespace svn
     error = svn_client_diff4(options,
                              path1.cstr (), ddata.r1().revision (),
                              path2.cstr (), ddata.r2().revision (),
-                             relativeTo.length()>0?relativeTo.cstr():QByteArray(0),
+                             relativeTo.length()>0?relativeTo.cstr():QByteArray(/*0*/),
                              internal::DepthToSvn(depth), ignoreAncestry, noDiffDeleted, ignore_contenttype,
                              APR_LOCALE_CHARSET,
                              ddata.outFile(),ddata.errFile(),
