@@ -45,7 +45,7 @@
 
 namespace svn
 {
-  Targets::Targets (const Pathes & targets)
+  Targets::Targets (const svn::Pathes & targets)
   {
     m_targets = targets;
   }
@@ -53,7 +53,7 @@ namespace svn
   Targets::Targets(const QStringList&targets)
   {
     m_targets.clear();
-    for (unsigned int i = 0; i < targets.size();++i) {
+    for (int i = 0; i < targets.size();++i) {
         if (targets[i].isEmpty()) {
             m_targets.push_back("");
         } else {
@@ -108,7 +108,7 @@ namespace svn
   {
   }
 
-  const apr_array_header_t *
+  apr_array_header_t *
   Targets::array (const Pool & pool) const
   {
     Pathes::const_iterator it;
@@ -144,8 +144,13 @@ namespace svn
     return m_targets.size ();
   }
 
+  const Path& Targets::operator [](size_t which)const
+  {
+    return m_targets[which];
+  }
+
   const Path
-  Targets::target (unsigned int which) const
+  Targets::target (Pathes::size_type which) const
   {
     if (m_targets.size () > which)
     {
