@@ -1,7 +1,7 @@
-/* 
+/*
  * Port for usage with qt-framework and development for kdesvn
  * (C) 2005-2007 by Rajko Albrecht
- * http://www.alwins-world.de/wiki/programs/kdesvn
+ * http://kdesvn.alwins-world.de
  */
 /*
  * ====================================================================
@@ -35,18 +35,8 @@
 
 // qt
 #include <qglobal.h>
-#if QT_VERSION < 0x040000
-
-#include <qstring.h>
-#include <qvaluelist.h>
-
-#else
-
 #include <QtCore>
 
-#endif
-
-
 namespace svn
 {
   class SVNQT_EXPORT Url
@@ -69,6 +59,14 @@ namespace svn
     static bool
     isValid (const QString& url);
 
+    /**
+     * Checks if @a url points to a local filesystem.
+     *
+     * @return true if url is accessed local without network.
+     */
+    static bool
+    isLocal(const QString& url);
+
     static QString
     transformProtokoll(const QString&);
 
@@ -78,11 +76,7 @@ namespace svn
      *
      * @return vector with entries like "file:", "http:"
      */
-#if QT_VERSION < 0x040000
-    static QValueList<QString>
-#else
-    static QList<QString>
-#endif
+    static QStringList
     supportedSchemas ();
   };
 }
