@@ -68,31 +68,3 @@ namespace svn {
       return svn_client_version()->minor;
     }
 }
-
-namespace svnqt {
-    SvnqtVersion::SvnqtVersion()
-    {
-    }
-
-    int SvnqtVersion::version_major()
-    {
-        return SVNQT_MAJOR;
-    }
-
-    int SvnqtVersion::version_minor()
-    {
-        return SVNQT_MINOR;
-    }
-
-    int SvnqtVersion::version_patch()
-    {
-        return SVNQT_PATCH;
-    }
-
-    bool SvnqtVersion::compatible(const SvnqtVersionTag&running)
-    {
-        return running._major==version_major() && running._major>=version_minor();
-    }
-
-    static SvnqtVersion svnqtVersion;
-}
